@@ -3,10 +3,7 @@
 //
 // It is recommended to fill all methods that shouldn't be called with:
 //
-//	panic("not implemented")
-//
-// in the body of the test, so that if the method is called the panic backtrace
-// points to the method definition in the test.
+//	panic(testutil.UnexpectedCall(arg1, arg2))
 package fakeservice
 
 import (
@@ -33,3 +30,16 @@ func (s *Service) Start(ctx context.Context) (err error) {
 func (s *Service) Shutdown(ctx context.Context) (err error) {
 	return s.OnShutdown(ctx)
 }
+
+// Refresher is the [service.Refresher] for tests.
+type Refresher struct {
+	OnRefresh func(ctx context.Context) (err error)
+}
+
+// type check
+var _ service.Refresher = (*Refresher)(nil)
+
+// Refresh implements the [service.Refresher] interface for *Refresher.
+func (r *Refresher) Refresh(ctx context.Context) (err error) {
+	return r.OnRefresh(ctx)
+}
